@@ -1,5 +1,5 @@
 
-
+from dateutil.parser import parse
 
 class Html_record:
 
@@ -16,7 +16,17 @@ class Html_record:
         content += '<dl class="row">'
 
         for i in keys:
-            content += self._record_line(i, value.get(i, None))
+
+            i_value = value.get(i, None)
+
+            # Convert to datetime and then to simple date format
+            try:
+                date_value = parse(i_value)
+                i_value = date_value.strftime("%Y-%m-%d, %H:%M")
+            except:
+                a = 1
+
+            content += self._record_line(i, i_value)
 
         content += '</dl>'
 
